@@ -6,7 +6,7 @@
  *
  * PHP version 4 (>= 4.3.x) or 5
  *
- * Copyright (C) 2006-2007 k.watanabe
+ * Copyright (C) 2006-2008 k.watanabe
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,9 +25,9 @@
  * -----------------------------------------------------------------------------
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
- * @copyright 2006-2007 k.watanabe
+ * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowLst.php,v 1.9 2007/12/29 09:15:29 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowLst.php,v 1.10 2008/01/15 09:19:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -42,9 +42,9 @@ require_once SYL_INCLUDE_DIR . '/framework/Adm/SyL_AdmFlow.php';
  *
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
- * @copyright 2006-2007 k.watanabe
+ * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowLst.php,v 1.9 2007/12/29 09:15:29 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowLst.php,v 1.10 2008/01/15 09:19:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmFlowLst extends SyL_AdmFlow
@@ -80,7 +80,7 @@ class SyL_AdmFlowLst extends SyL_AdmFlow
         switch ($data->get('adm_ajax')) {
         case 'import':
         case 'json':
-            $data->apply('mb_convert_encoding', SYL_ENCODE_INTERNAL, SYL_ENCODE_AJAX);
+            $data->apply('mb_convert_encoding', SYL_ENCODE_INTERNAL, SYL_ENCODE_JS);
             break;
         }
         parent::preExecute($data, $context);
@@ -99,11 +99,11 @@ class SyL_AdmFlowLst extends SyL_AdmFlow
 
         switch ($data->get('adm_ajax')) {
         case 'import':
-            $data->apply('mb_convert_encoding', SYL_ENCODE_AJAX, SYL_ENCODE_INTERNAL);
+            $data->apply('mb_convert_encoding', SYL_ENCODE_JS, SYL_ENCODE_INTERNAL);
             $context->setViewType('js.ajax');
             break;
         case 'json':
-            $data->apply('mb_convert_encoding', SYL_ENCODE_AJAX, SYL_ENCODE_INTERNAL);
+            $data->apply('mb_convert_encoding', SYL_ENCODE_JS, SYL_ENCODE_INTERNAL);
             $context->setViewType('json');
             break;
         }
