@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DataJs.php,v 1.4 2008/02/02 14:40:45 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DataJs.php,v 1.5 2008/03/01 05:01:22 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DataJs.php,v 1.4 2008/02/02 14:40:45 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DataJs.php,v 1.5 2008/03/01 05:01:22 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DataJs extends SyL_Data
@@ -72,6 +72,20 @@ class SyL_DataJs extends SyL_Data
      * @var string
      */
     var $separater = ',';
+    /**
+     * JSONPХåؿ̾
+     * 
+     * @access private
+     * @var array
+     */
+    var $js_callback = '';
+    /**
+     * JSONPХåѥ᡼̾
+     *
+     * @access private
+     * @var string
+     */
+    var $js_callback_parameter = 'callback';
 
     /**
      * ϥ饹ɲ
@@ -95,6 +109,28 @@ class SyL_DataJs extends SyL_Data
         return $this->imports;
     }
 
+    /**
+     * JSONPХåؿ򥻥å
+     * 
+     * @access public
+     * @param string JSONPХåؿ
+     */
+    function setJsCallback($js_callback)
+    {
+        $this->js_callback = $js_callback;
+    }
+
+    /**
+     * JSONPХåؿ
+     * 
+     * @access public
+     * @return string JSONPХåؿ
+     */
+    function getJsCallback()
+    {
+        return $this->js_callback;
+    }
+
     /**
      * JavaScriptϾ򥻥å
      * 
@@ -142,6 +178,16 @@ class SyL_DataJs extends SyL_Data
         if (is_string($js)) {
             $this->imports = array_merge($this->imports, explode($this->separater, $js));
         }
+        // JSONPХåؿѥ᡼
+        $js_callback = $this->get($this->js_callback_parameter);
+        if (is_string($js_callback)) {
+            // Хåؿå
+            if (preg_match('/^[a-zA-Z0-9_\$\.\[\]]+$/', $js_callback)) {
+                $this->js_callback = $js_callback;
+            } else {
+                trigger_error("[SyL error] Invalid javascript callback function ({$js_callback})", E_USER_ERROR);
+            }
+        }
     }
 
     /**
