@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.24 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.25 2008/02/02 14:40:44 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.24 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.25 2008/02/02 14:40:44 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ErrorWeb extends SyL_Error
@@ -53,6 +53,20 @@ class SyL_ErrorWeb extends SyL_Error
      */
     var $display_source_line = 9;
 
+    /**
+     * 404 Not Found ɽ
+     *
+     * @access public
+     */
+    function forward404Detail()
+    {
+        SyL_Loggers::notice("404 Not Found");
+        SyL_Response::setStatusHeader('404');
+
+        include_once SYL_ERROR_FORWARD_FILE_404;
+        exit;
+    }
+
     /**
      * Ķ̥顼
      * 
