@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewJs.php,v 1.9 2008/02/02 14:40:44 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewJs.php,v 1.10 2008/03/01 05:01:22 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewJs.php,v 1.9 2008/02/02 14:40:44 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewJs.php,v 1.10 2008/03/01 05:01:22 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ViewJs extends SyL_View
@@ -145,10 +145,10 @@ class SyL_ViewJs extends SyL_View
         $js = ob_get_clean();
 
         // ǥȺ
-        $js = preg_replace('/(\r\n|\r|\n)[ ]*/', "\n", $js);
+        $js = preg_replace('/(\r\n|\r|\n)[ \t]*/', "\n", $js);
         // Ⱥ
-        //$js = preg_replace('/\/\*([^\/]*)\*\//s', "", $js);
-        //$js = preg_replace('/\/\/([^(\r\n|\r|\n)]*)(\r\n|\r|\n)/', "", $js);
+        $js = preg_replace('/\/\*(.*?)\*\//s', "", $js);
+        $js = preg_replace('/(\r\n|\r|\n)[ ]*\/\/([^(\r\n|\r|\n)]*)(\r\n|\r|\n)/', '$1', $js);
 
         return $js;
     }
