@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_HttpClient.php,v 1.4 2008/01/20 15:09:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_HttpClient.php,v 1.5 2008/02/02 14:40:44 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -37,9 +37,13 @@
  */
 require_once dirname(__FILE__) . '/../SyL_Socket.php';
 /**
- * HTTP饤ȥѥ᡼饹
+ * HTTP饤ȥꥯȥ饹
  */
-require_once 'SyL_HttpClientParameter.php';
+require_once 'SyL_HttpClientRequest.php';
+/**
+ * HTTP饤ȥ쥹ݥ󥹥饹
+ */
+require_once 'SyL_HttpClientResponse.php';
 
 /**
  * HTTP饤ȥ饹
@@ -48,7 +52,7 @@ require_once 'SyL_HttpClientParameter.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_HttpClient.php,v 1.4 2008/01/20 15:09:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_HttpClient.php,v 1.5 2008/02/02 14:40:44 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_HttpClient
@@ -119,9 +123,9 @@ class SyL_HttpClient
      * @param string ꥯURL
      * @param string ꥯȥ᥽å
      */
-    function &createParameter($url='/', $method='GET')
+    function &createRequest($url='/', $method='GET')
     {
-        $parameter =& new SyL_HttpClientParameter($url, $method);
+        $parameter =& new SyL_HttpClientRequest($url, $method);
         return $parameter;
     }
 
@@ -154,7 +158,7 @@ class SyL_HttpClient
      * @param object ꥯȥѥ᡼֥
      * @param string 饤ȥ󥳡
      */
-    function &send(&$parameter, $client_encode='')
+    function &sendRequest(&$parameter, $client_encode='')
     {
         // ۥȥإåѥѥ᡼å
         $parameter->setHeader('host', $this->host);
@@ -176,7 +180,7 @@ class SyL_HttpClient
         $data = $socket->receiveAll(true);
         $socket->close();
 
-        return $this->createResult($data, $client_encode);
+        return $this->createResponse($data, $client_encode);
     }
 
     /**
@@ -186,11 +190,10 @@ class SyL_HttpClient
      * @param string 쥹ݥ󥹥ǡ
      * @param string 饤ȥ󥳡
      */
-    function &createResult(&$data, $client_encode='')
+    function &createResponse(&$data, $client_encode='')
     {
-        include_once 'SyL_HttpClientResult.php';
-        $result =& new SyL_HttpClientResult($data, $client_encode);
-        return $result;
+        $response =& new SyL_HttpClientResponse($data, $client_encode);
+        return $response;
     }
 
     /**
