@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Cache.php,v 1.16 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Cache.php,v 1.17 2008/03/01 05:01:22 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Cache.php,v 1.16 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Cache.php,v 1.17 2008/03/01 05:01:22 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Cache
@@ -132,11 +132,12 @@ class SyL_Cache
      * LbṼL[擾
      *
      * @access public
-     * @param string LbVL[
+     * @param bool MD5tL[tO
+     * @return string LbVL[
      */
-    function getKey()
+    function getKey($md5=true)
     {
-        return $this->prefix . $this->key_md5;
+        return $this->prefix . ($md5 ? $this->key_md5 : '');
     }
 
     /**
