@@ -27,25 +27,25 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_UtilUseragent.php,v 1.6 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_UtilUseragent.php,v 1.7 2008/03/01 05:01:22 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
 
 /**
- * [U[G[WFgNX
+ * 桼Ƚꥯ饹
  *
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_UtilUseragent.php,v 1.6 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_UtilUseragent.php,v 1.7 2008/03/01 05:01:22 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_UtilUserAgent
 {
     /**
-     * [U[G[WFg
+     * 桼
      *
      * @access private
      * @var string
@@ -53,7 +53,7 @@ class SyL_UtilUserAgent
     var $user_agent = '';
 
     /**
-     * vbgtH[iOSjzi}X^j
+     * ץåȥեĶOSʥޥ
      *
      * @access private
      * @var array
@@ -89,7 +89,9 @@ class SyL_UtilUserAgent
       'openbsd'         => 'OpenBSD',
       'Fedora'          => 'Fedora Core',
       'CentOS'          => 'CentOS',
-      'Ubuntu'          => 'Ubuntu',
+      'Ubuntu'          => 'Ubuntu Linux',
+      'Mandriva'        => 'Mandriva Linux',
+      'Red Hat'         => 'Red Hat Linux',
       'gnu'             => 'GNU/Linux',
       'vine'            => 'Vine Linux',
       'linux'           => 'Linux',
@@ -102,7 +104,7 @@ class SyL_UtilUserAgent
     );
 
     /**
-     * uEUz
+     * ֥饦
      *
      * @access private
      * @var array
@@ -145,7 +147,7 @@ class SyL_UtilUserAgent
     );
 
     /**
-     * oCLAzi}X^j
+     * Х륭ꥢʥޥ
      *
      * @access private
      * @var array
@@ -164,7 +166,7 @@ class SyL_UtilUserAgent
     );
 
     /**
-     * ROBOTzi}X^j
+     * ROBOTʥޥ
      *
      * @access private
      * @var array
@@ -206,6 +208,7 @@ class SyL_UtilUserAgent
       'RedBot'        => 'RedBot',
       'Robo Crawler'  => 'Robo Crawler',
       'Snapbot'       => 'Snapbot',
+      'SnapPreviewBot' => 'SnapPreviewBot',
       'Steeler'       => 'Steeler',
       'SurveyBot'     => 'SurveyBot',
       'YodaoBot'      => 'YodaoBot',
@@ -216,25 +219,29 @@ class SyL_UtilUserAgent
     );
 
     /**
-     * RXgN^
+     * 󥹥ȥ饯
      *
      * @access public
-     * @param string [U[G[WFg
+     * @param string 桼
      */
     function SyL_UtilUserAgent($user_agent='')
     {
         if ($user_agent) {
             $this->user_agent = $user_agent;
         } else {
-            $this->user_agent = isset($_SERVER['HTTP_USER_AGENT']) ? $_SERVER['HTTP_USER_AGENT'] : '';
+            if (isset($_SERVER['HTTP_USER_AGENT'])) {
+                $this->user_agent = $_SERVER['HTTP_USER_AGENT'];
+            } else {
+                trigger_error("[SyL error] `HTTP_USER_AGENT' not found", E_USER_ERROR);
+            }
         }
     }
 
     /**
-     * oCs
+     * ХȽԤ
      *
      * @access public
-     * @return bool true: oCAfalse: oCȊO
+     * @return bool true: Х롢false: Хʳ
      */
     function isMobile()
     {
@@ -242,10 +249,10 @@ class SyL_UtilUserAgent
     }
 
     /**
-     * {bgs
+     * ܥåȽԤ
      *
      * @access public
-     * @return bool true: {bgAfalse: {bgȊO
+     * @return bool true: ܥåȡfalse: ܥåȰʳ
      */
     function isRobot()
     {
@@ -253,10 +260,10 @@ class SyL_UtilUserAgent
     }
 
     /**
-     * vbgtH[iOSj擾
+     * ץåȥեĶOSˤ
      *
      * @access public
-     * @return string vbgtH[iOSj
+     * @return string ץåȥեĶOS
      */
     function getPlatform()
     {
@@ -269,10 +276,10 @@ class SyL_UtilUserAgent
     }
 
     /**
-     * uEU擾
+     * ֥饦̾
      *
      * @access public
-     * @return string uEU
+     * @return string ֥饦̾
      */
     function getBrowser()
     {
@@ -286,10 +293,10 @@ class SyL_UtilUserAgent
     }
 
     /**
-     * LA擾
+     * ꥢ̾
      *
      * @access public
-     * @return string LA
+     * @return string ꥢ̾
      */
     function getCarrier()
     {
@@ -302,25 +309,25 @@ class SyL_UtilUserAgent
     }
 
     /**
-     * oC̋@햼擾
+     * Хε̾
      *
      * @access public
-     * @return string oC̋@햼
+     * @return string Хε̾
      */
     function getMobileModel()
     {
         switch ($this->getCarrier()) {
         case 'DoCoMo':
-            // jDoCoMo/1.0/D505i/c20/TB/W20H10/serNMAIA000001
+            // DoCoMo/1.0/D505i/c20/TB/W20H10/serNMAIA000001
             if (preg_match('/^DoCoMo\/\d\.0\/([^\/]+)\/(.*)$/i', $this->user_agent, $matches)) {
                 return $matches[1];
-            // jDoCoMo/2.0 F900i(c100;TC;W22H12)
+            // DoCoMo/2.0 F900i(c100;TC;W22H12)
             } else if (preg_match('/^DoCoMo\/\d\.0[ ]*([^\(]+)(.*)$/i', $this->user_agent, $matches)) {
                 return $matches[1];
             }
             break;
         case 'KDDI(au)':
-            // jKDDI-HI32 UP.Browser/6.2.0.6.2 (GUI) MMP/2.0
+            // KDDI-HI32 UP.Browser/6.2.0.6.2 (GUI) MMP/2.0
             //     UP.Browser/3.04-ST13 UP.Link/3.4.5.9
             if (preg_match('/^([^\-]+)\-([^ ]+) (.+)$/i', $this->user_agent, $matches)) {
                 return $matches[2];
@@ -334,14 +341,14 @@ class SyL_UtilUserAgent
                 case 'C': return '702sMO';
                 case 'V': return '702MO';
                 }
-            // jSoftBank/1.0/910T/TJ001/SN*** Browser/NetFront/3.3 Profile/MIDP-2.0 Configuration/CLDC-1.1
+            // SoftBank/1.0/910T/TJ001/SN*** Browser/NetFront/3.3 Profile/MIDP-2.0 Configuration/CLDC-1.1
             } else if (preg_match('/^([^\/]+)\/([^\/]+)\/([^\/]+)\/?(.*)$/i', $this->user_agent, $matches)) {
                 return $matches[3];
             }
             break;
         case 'WILLCOM':
-            // jMozilla/4.0 (compatible; MSIE 4.01; Windows CE; SHARP/WS003SH; PPC; 480x640)
-            // jMozilla/3.0(WILLCOM;SANYO/WX310SA/2;1/1/C128) NetFront/3.3
+            // Mozilla/4.0 (compatible; MSIE 4.01; Windows CE; SHARP/WS003SH; PPC; 480x640)
+            // Mozilla/3.0(WILLCOM;SANYO/WX310SA/2;1/1/C128) NetFront/3.3
             if (strpos($this->user_agent, 'PDXGW') !== false) {
                 return 'EDGE LINK';
             } else if (preg_match('/^Mozilla\/\d\.0([^\/]+)\/([^;\/]+);(.*)$/i', $this->user_agent, $matches)) {
@@ -355,10 +362,10 @@ class SyL_UtilUserAgent
     }
 
     /**
-     * {bg擾
+     * ܥå̾
      *
      * @access public
-     * @return string {bg
+     * @return string ܥå̾
      */
     function getRobot()
     {
